********************************************************************************
*******************Dividend Policy in the German Empire*************************
********************************************************************************

** Please make sure that the file "dividend_policy_panel.dta" and this do file**
** are stored in the same folder **

version 16.1
clear all
set more off

** make folders for figures and tables
capture mkdir tables
capture mkdir figures




********************************************************************************
use "dividend_policy_panel.dta", clear
sort firmennr year

generate div_increase = 1 if DIV[_n]>DIV[_n-1] & firmennr[_n] == firmennr[_n-1] & DIV[_n-1]!=. & DIV[_n]!=.
replace div_increase = 0 if DIV[_n]<=DIV[_n-1] & firmennr[_n] == firmennr[_n-1] & DIV[_n-1]!=. & DIV[_n]!=.
generate div_decrease = 1 if DIV[_n]<DIV[_n-1] & firmennr[_n] == firmennr[_n-1] & DIV[_n-1]!=. & DIV[_n]!=.
replace div_decrease = 0 if DIV[_n]>=DIV[_n-1] & firmennr[_n] == firmennr[_n-1] & DIV[_n-1]!=. & DIV[_n]!=.


********************************************************************************
*************************Table 1: Descriptive Statistics************************
********************************************************************************
estpost summarize DIV lagdiv delta_DIV div_increase div_decrease DPAR PROFIT profit_increase ROE RM reserve_share RESERVE_EXCESS log_assets gASSETS max_cap_raise seo_last_five seo_next_five Q DEBT age_firm one_vote div_board div_auto div_agm banker AktNov HGB  if T>=4, d
eststo descriptive
esttab descriptive using "tables\table_1.rtf", cells("mean(fmt(%20.1fc)) sd(fmt(%20.1fc)) min(fmt(%20.1fc)) max(fmt(%20.1fc)) count(fmt(%20.0fc))") nomtitle nonumber noobs label replace

********************************************************************************
***********************Table 2: Determinats of dividend changes*****************
********************************************************************************

***DIV
logit div_increase ROE if T>=4, or vce(cluster firmennr)
eststo logit_m1: margins, dydx(*) post

logit div_increase ROE log_assets RESERVE_EXCESS gASSETS Q DEBT RM i.one_vote age_firm if T>=4, or vce(cluster firmennr)
eststo logit_m2: margins, dydx(*) post

logit div_decrease ROE if T>=4, or vce(cluster firmennr)
eststo logit_m3: margins, dydx(*) post

logit div_decrease ROE log_assets RESERVE_EXCESS gASSETS Q DEBT RM i.one_vote age_firm if T>=4, or vce(cluster firmennr)
eststo logit_m4: margins, dydx(*) post


* make table
esttab logit_m1 logit_m2 logit_m3 logit_m4 using "tables/table_2.rtf", cells(b(fmt(3) star) se(fmt(3) par)) stats(N r2_p, fmt(%20.0fc 2) labels( `"Obs."' `"Pseudo \(R^{2}\)"')) starlevels(** 0.05 *** 0.01) nobase title("Table 2: Determinats of dividend payment") numbers mtitles("Logit" "Logit" "Logit" "Logit") mgroups("Dividend increase" "Dividend decrease", pattern(1 0 1 0)) label collabels(none) nogaps addnotes("Note: The table reports the average marginal effects of the estimated coefficients. Cluster robust standard errors in parentheses (clusterlevel = firm). ***, ** indicate significance at the 1%, and 5% level.") replace


********************************************************************************
****************Table 3: Determinats of dividend payout ratio*******************
********************************************************************************

***DPAR
eststo tobit_m1: tobit DPAR ROE if T>=4, ll(0) ul(1) vce(cluster firmennr)

eststo tobit_m2: tobit DPAR ROE log_assets RESERVE_EXCESS gASSETS Q DEBT RM i.one_vote age_firm i.banker if T>=4, ll(0) ul(1) vce(cluster firmennr)

* make table
esttab tobit_m1 tobit_m2 using "tables/table_3.rtf", cells(b(fmt(3) star) se(fmt(3) par)) stats(N ll, fmt(%20.0fc 2) labels( `"Obs."' `"Pseudo Loglikelihood"')) starlevels(* 0.1 ** 0.05 *** 0.01) nobase title("Table 3: Determinats of dividend payout ratio") numbers mtitles("Tobit" "Tobit" "Tobit") mgroups("Full Sample" "w/o Financial Firms", pattern(1 0 1)) label collabels(none) nogaps addnotes("Note: Cluster robust standard errors in parentheses (clusterlevel = firm). ***, **, * indicate significance at the 1%, 5%, 10% level.") replace


********************************************************************************
*******************Table 4 Dividend adjustment. Baseline Estimates**************
********************************************************************************

*** Col (1): Lintner, firm fixed effects
eststo lintner_fe: xtreg DIV l1.DIV PROFIT if T>=4, fe vce(cluster firmennr)   // actual values
predict res_e if e(sample), e
corr res_e L.res_e
xtistest res_e, lags(1)
drop  res_e 
estadd local autocorrelation "NO"
estadd local laggedresid "0.27"

// checking for multicollinarity
reg DIV l1.DIV PROFIT i.firmennr if T>=4,vce(cluster firmennr)
estat vif // no hint to multicollinarity

*** Col (2): Linter, Least Square Dummy Variable Correction
eststo lintner_lsdvc: xtlsdvc DIV PROFIT if T>=4, initial(ab) vcov(2) first // actual values
predict res_e if e(sample), e 
corr res_e L.res_e
xtistest res_e, lags(1)
drop  res_e 
estadd local autocorrelation "NO"
estadd local laggedresid "0.26"

*** Col (3): Lintner, Blundell-Bond
eststo lintner_bb: xtdpdsys DIV PROFIT if T>=4, vce(robust) // actual values
estat abond
predict res_e if e(sample), e
corr res_e L.res_e
drop res_e 

estadd local autocorrelation "YES"
estadd local laggedresid "0.48"


*** make table 4
esttab lintner_fe lintner_lsdvc lintner_bb using "tables/table_4.rtf", cells(b(fmt(2) star) se(fmt(3) par)) stats(N  N_g  g_avg r2_a autocorrelation laggedresid, fmt(%20.0fc %20.0fc %20.1fc 2 2 %20.2fc) labels( `"Obs."' `"Groups"' `"Average Panel Length"' `"Adj. \(R^{2}\)"' `"Autocorrelation"' `"Correlation of lagged residuals"' )) keep(L.DIV PROFIT) title("Table 4: Baseline estimates") starlevels(* 0.1 ** 0.05 *** 0.01) numbers mtitles("Fixed Effects" "LSDVC" "Blundell-Bond") label collabels(none) nogaps addnotes("Note: HAC errors in parentheses. ***, **, * indicate significance at the 1%, 5%, 10% level. Autocorrelation: panel models (col. (1), and (2) use the Portmanteau test for panel serial correlation; Blundell-Bond (col. 3) uses the  Arellano-Bond test for serial correlation in the first-differenced residuals.") replace

********************************************************************************
******************Table 5: Dividend adjustment and corporate law****************
********************************************************************************
*** Col (1): Linter, firm fixed effects (Aktienrechtsnovelle)
eststo lintner_fe_law: xtreg DIV l1.DIV PROFIT RESERVE_EXCESS Q i.AktNov i.AktNov#c.l1.DIV i.AktNov#c.PROFIT i.AktNov#c.RESERVE_EXCESS i.AktNov#c.Q if T>=4 & year == 1880 | year == 1881 | year == 1882 | year == 1883 | year == 1885 | year == 1886 | year == 1887 | year == 1888, fe vce(cluster firmennr) // actual values

*test for autocorrelation
predict res_e if e(sample), e
corr res_e L.res_e
xtistest res_e, lags(1)
drop res_e
estadd local autocorrelation "NO"
estadd local laggedresid "0.04"


*** Col (2): Linter, firm fixed effects (Handelsgesetzbuch)
eststo lintner_fe_hgb: xtreg DIV l1.DIV PROFIT RESERVE_EXCESS Q i.HGB i.HGB#c.l1.DIV i.HGB#c.PROFIT i.HGB#c.RESERVE_EXCESS i.HGB#c.Q if T>=4 & year == 1896 | year == 1897 | year == 1898 | year == 1899 | year == 1901 | year == 1902 | year == 1903 | year == 1904, fe vce(cluster firmennr) // actual values
*test for autocorrelation
predict res_e if e(sample), e 
corr res_e L.res_e
xtistest res_e, lags(1)
drop res_e
estadd local autocorrelation "NO"
estadd local laggedresid "0.22"

***make table 5

esttab lintner_fe_law lintner_fe_hgb using "tables/table_5.rtf", cells(b(fmt(2) star) se(fmt(3) par)) stats(N  N_g  g_avg r2_a autocorrelation laggedresid, fmt( %20.0fc %20.0fc %20.1fc %20.2fc 2 %20.2fc) labels(`"Obs."' `"Groups"' `"Average Panel Length"' `"Adj. \(R^{2}\)"'`"Autocorrelation"' `"Correlation of lagged residuals"' )) drop(_cons) nobase title("Table 6: Dividend adjustment and corporate law") starlevels(* 0.1 ** 0.05 *** 0.01) numbers mtitles("" "" ) mgroups("Aktienrechtsnovelle" "HGB", pattern(1 1)) label collabels(none) nogaps addnotes("Note: Robust standard errors in parentheses. ***, **, * indicate significance at the 1%, 5%, 10% level. Autocorrelation: panel models use the Portmanteau test for panel serial correlation") replace

***true diffindiff*** response to referee
generate treatafter = reserve_treatment*AktNov
generate period = 1 if year == 1880 | year == 1881 | year == 1882 | year == 1883 | year == 1885 | year == 1886 | year == 1887 | year == 1888
replace period = 0 if period == .
label var reserve_treatment "Treatment Group (TG)"
label var AKtNov "post Novelle 1884"
label var treatafter "TG post Novelle 1884"
eststo difindif_base: xtreg DIV i.reserve_treatment i.AktNov i.treatafter if period==1, vce(cluster firmennr)
eststo difindif_full: xtreg DIV i.reserve_treatment i.AktNov i.treatafter lagdiv PROFIT Q i.treatafter#c.lagdiv if period==1, vce(cluster firmennr)

esttab difindif_base difindif_full using "tables/difindif.rtf", cells(b(fmt(2) star) se(fmt(3) par)) stats(N  N_g  g_avg r2_b , fmt( %20.0fc %20.0fc %20.1fc %20.2fc 2) labels(`"Obs."' `"Groups"' `"Average Panel Length"' `"\(R^{2}\)"')) drop(_cons) nobase title("Table 6: Dividend adjustment and corporate law") starlevels(* 0.1 ** 0.05 *** 0.01) numbers mtitles("" "" ) label collabels(none) nogaps replace

********************************************************************************
**************Table 6: Dividend adjustment and Corporate Govenance**************
********************************************************************************
*Col (1): Full sample
eststo lintner_fe_cg: xtreg DIV l1.DIV PROFIT RESERVE_EXCESS Q i.one_vote b2.dist_rule i.banker i.one_vote#c.l1.DIV i.one_vote#c.PROFIT i.one_vote#c.RESERVE_EXCESS i.one_vote#c.Q b2.dist_rule#c.l1.DIV b2.dist_rule#c.PROFIT b2.dist_rule#c.RESERVE_EXCESS b2.dist_rule#c.Q i.banker#c.l1.DIV i.banker#c.RESERVE_EXCESS if T>=4, fe vce(cluster firmennr) // actual values


*test for autocorrelation
predict res_e if e(sample), e 
corr res_e L.res_e
xtistest res_e, lags(1)
drop res_e
estadd local autocorrelation "NO"
estadd local laggedresid "0.31"

*** Col (2) with capital increase
eststo cap_raise_over2: xtreg DIV l1.DIV PROFIT RESERVE_EXCESS Q i.one_vote b2.dist_rule i.banker i.one_vote#c.l1.DIV i.one_vote#c.PROFIT i.one_vote#c.RESERVE_EXCESS i.one_vote#c.Q b2.dist_rule#c.l1.DIV b2.dist_rule#c.PROFIT b2.dist_rule#c.RESERVE_EXCESS b2.dist_rule#c.Q i.banker#c.l1.DIV i.banker#c.RESERVE_EXCESS if T>=4 & seo_last_five==1, fe vce(cluster firmennr)

*test for autocorrelation
predict res_e if e(sample), e //overall error component (only in sample prediction)
corr res_e L.res_e
xtistest res_e, lags(1)
drop res_e
estadd local autocorrelation "NO"
estadd local laggedresid "0.25"

*** Col (3) without capital increase
eststo cap_raise_max2: xtreg DIV l1.DIV PROFIT RESERVE_EXCESS Q i.one_vote b2.dist_rule i.banker i.one_vote#c.l1.DIV i.one_vote#c.PROFIT i.one_vote#c.RESERVE_EXCESS i.one_vote#c.Q b2.dist_rule#c.l1.DIV b2.dist_rule#c.PROFIT b2.dist_rule#c.RESERVE_EXCESS b2.dist_rule#c.Q i.banker#c.l1.DIV i.banker#c.RESERVE_EXCESS if T>=4 & seo_next_five==1, fe vce(cluster firmennr)

predict res_e if e(sample), e //overall error component (only in sample prediction)
corr res_e L.res_e
xtistest res_e, lags(1)
drop res_e
estadd local autocorrelation "NO"
estadd local laggedresid "0.16"

*** Col (4) with number cap increases
eststo nb_cap_raise: xtreg DIV l1.DIV PROFIT RESERVE_EXCESS Q nb_capitalraise i.one_vote b2.dist_rule i.banker i.one_vote#c.l1.DIV i.one_vote#c.PROFIT i.one_vote#c.RESERVE_EXCESS i.one_vote#c.Q b2.dist_rule#c.l1.DIV b2.dist_rule#c.PROFIT b2.dist_rule#c.RESERVE_EXCESS b2.dist_rule#c.Q i.banker#c.l1.DIV i.banker#c.RESERVE_EXCESS c.nb_capitalraise#c.l1.DIV if T>=4, fe vce(cluster firmennr)

predict res_e if e(sample), e //overall error component (only in sample prediction)
corr res_e L.res_e
xtistest res_e, lags(1)
drop res_e
estadd local autocorrelation "NO"
estadd local laggedresid "0.31"


esttab lintner_fe_cg cap_raise_over2 cap_raise_max2 nb_cap_raise using "tables/table_6.rtf", cells(b(fmt(2) star) se(fmt(3) par)) stats(N  N_g  g_avg r2_a autocorrelation laggedresid, fmt( %20.0fc %20.0fc %20.1fc %20.2fc 2 %20.2fc) labels(`"Obs."' `"Groups"' `"Average Panel Length"' `"Adj. \(R^{2}\)"' `"Autocorrelation"' `"Correlation of lagged residuals"')) drop(_cons) nobase title("Table 6: Dividend adjustment and corporate governance") starlevels(* 0.1 ** 0.05 *** 0.01) numbers mtitles("Full Sample" "SEO last five years" "SEO next five years" "Number SEOs" ) mgroups("Lintner (Fixed Effects)", pattern(1 0)) label collabels(none) nogaps addnotes("Note: Robust standard errors in parentheses. ***, **, * indicate significance at the 1%, 5%, 10% level. Autocorrelation: panel models use the Portmanteau test for panel serial correlation. Base category decision rule: automatic distribution via Articles of Association") replace

tab max_cap_raise if T>=4

********************************************************************************
******************Table 7: Alternative Explanations*****************************
********************************************************************************
*** Col (1) Capital structure & monitoring
eststo cap_structure: xtreg DIV l1.DIV PROFIT RESERVE_EXCESS Q i.one_vote b2.dist_rule i.banker i.one_vote#c.l1.DIV i.one_vote#c.PROFIT i.one_vote#c.RESERVE_EXCESS i.one_vote#c.Q b2.dist_rule#c.l1.DIV b2.dist_rule#c.PROFIT b2.dist_rule#c.RESERVE_EXCESS b2.dist_rule#c.Q i.banker#c.l1.DIV i.banker#c.RESERVE_EXCESS DEBT c.DEBT#i.banker if T>=4, fe vce(cluster firmennr)
*test for autocorrelation
predict res_e if e(sample), e //overall error component (only in sample prediction)
corr res_e L.res_e
xtistest res_e, lags(1)
drop res_e
estadd local autocorrelation "NO"
estadd local laggedresid "0.31"
estadd local baseline "Yes"

*** Col (2) Life-cycle
eststo life_cycle: xtreg DIV l1.DIV PROFIT RESERVE_EXCESS Q i.one_vote b2.dist_rule i.banker i.one_vote#c.l1.DIV i.one_vote#c.PROFIT i.one_vote#c.RESERVE_EXCESS i.one_vote#c.Q b2.dist_rule#c.l1.DIV b2.dist_rule#c.PROFIT b2.dist_rule#c.RESERVE_EXCESS b2.dist_rule#c.Q i.banker#c.l1.DIV i.banker#c.RESERVE_EXCESS age_firm  c.age_firm#c.l1.DIV log_assets c.log_assets#c.l1.DIV if T>=4, fe vce(cluster firmennr)
*test for autocorrelation
predict res_e if e(sample), e //overall error component (only in sample prediction)
corr res_e L.res_e
xtistest res_e, lags(1)
drop res_e
estadd local autocorrelation "NO"
estadd local laggedresid "0.30"
estadd local baseline "Yes"


*** Col (3) Profit increase
eststo profit_increase: xtreg DIV l1.DIV PROFIT RESERVE_EXCESS Q i.one_vote b2.dist_rule i.banker i.one_vote#c.l1.DIV i.one_vote#c.PROFIT i.one_vote#c.RESERVE_EXCESS i.one_vote#c.Q b2.dist_rule#c.l1.DIV b2.dist_rule#c.PROFIT b2.dist_rule#c.RESERVE_EXCESS b2.dist_rule#c.Q i.banker#c.l1.DIV i.banker#c.RESERVE_EXCESS i.profit_increase i.profit_increase#c.l1.DIV  if T>=4, fe vce(cluster firmennr)
*test for autocorrelation
predict res_e if e(sample), e //overall error component (only in sample prediction)
corr res_e L.res_e
xtistest res_e, lags(1)
drop res_e
estadd local autocorrelation "NO"
estadd local laggedresid "0.25"
estadd local baseline "Yes"


global varlist "DEBT 1.banker#c.DEBT age_firm c.age_firm#cL.DIV log_assets c.log_assets#cL.DIV 1.profit_increase 1.profit_increase#cL.DIV"

esttab cap_structure life_cycle profit_increase using "tables/table_7.rtf" , cells(b(fmt(2) star) se(fmt(3) par)) stats(N  N_g  g_avg r2_a autocorrelation laggedresid baseline, fmt( %20.0fc %20.0fc %20.1fc %20.2fc 2 %20.2fc 2) labels(`"Obs."' `"Groups"' `"Average Panel Length"' `"Adj. \(R^{2}\)"' `"Autocorrelation"' `"Correlation of lagged residuals"'`"Baseline Variables"')) keep($varlist)  nobase title("Table 8: Alternative Explanations") starlevels(* 0.1 ** 0.05 *** 0.01) numbers mtitles("Capital Structure" "Life-Cycle" "Profit increase") mgroups("Lintner (Fixed Effects)", pattern(1 0 0)) label collabels(none) nogaps addnotes("Robust standard errors in parentheses. ***, **, * indicate significance at the 1%, 5%, 10% level. Autocorrelation: panel models use the Portmanteau test for panel serial correlation.") replace

esttab cap_structure life_cycle profit_increase using "tables/table_A3.rtf" , cells(b(fmt(2) star) se(fmt(3) par)) stats(N  N_g  g_avg r2_a autocorrelation laggedresid, fmt( %20.0fc %20.0fc %20.1fc %20.2fc 2 %20.2fc) labels(`"Obs."' `"Groups"' `"Average Panel Length"' `"Adj. \(R^{2}\)"' `"Autocorrelation"' `"Correlation of lagged residuals"')) drop(_cons)  nobase title("Table A7: Alternative Explanations - full table") starlevels(* 0.1 ** 0.05 *** 0.01) numbers mtitles("Capital Structure" "Life-Cycle" "Profit increase") mgroups("Lintner (Fixed Effects)", pattern(1 0 0)) label collabels(none) nogaps addnotes("Note: Robust standard errors in parentheses. ***, **, * indicate significance at the 1%, 5%, 10% level. Autocorrelation: panel models use the Portmanteau test for panel serial correlation.") replace

********************************************************************************
************Table A2: Composition of full sample vs reduced sample**************
********************************************************************************

estpost tabulate sektordummy
eststo tabulate_full_sample
estpost tabulate sektordummy if T>=4
eststo reduced_sample

esttab tabulate_full_sample reduced_sample using "tables/table_A2.rtf", cells("b(label(Freq.) fmt(%9.0fc)) pct(label(Pct.) fmt(%9.1fc))") varlabels(`e(labels)', blist(Total)) nonumber nomtitle mgroups("Full Sample" "Reduced Sample (T>=4)", pattern(1 1)) noobs replace

clear
********************************************************************************
***********************************Figures**************************************
********************************************************************************

********************************************************************************
************************************Figure 1 & 2********************************
********************************************************************************
use "dividend_policy_panel.dta", clear
generate number_firms = 1

collapse (sum) one_vote div_agm div_auto div_board number_firms if T>=4, by(year)
sort year

generate share_one_vote = (one_vote/number_firms)*100
label var share_one_vote "Share 'one vote' rule"
generate share_div_agm = (div_agm/number_firms)*100
label var share_div_agm "Share 'agm decides about dividend' rule"
generate share_div_board = (div_board/number_firms)*100
label var share_div_board "Share 'board decides about dividend' rule"
generate share_div_auto = (div_auto/number_firms)*100
label var share_div_auto "Share 'automatic distribution of dividend' rule"

label var number_firms "Number firms"

*** Figure 1
twoway (bar number_firms year, fcolor(gs9) lcolor(black) yaxis(1)) (bar number_firms year if year==1884 | year == 1900, fcolor(black%50) lcolor(black) yaxis(1)) (connected share_one_vote year, yaxis(2) msize(tiny) mcolor(black) lcolor(black)), ytitle("Number firms",  margin(small) axis(1)) ylabel(, nogrid)   note("") graphregion(fcolor(white) lcolor(none) lwidth(none)) subtitle(, fcolor(gs10) lcolor(black)) legend(order(1 "Number firms" 3 "Share 'one vote'" ))
graph export "figures\figure_1.pdf", as(pdf) name("Graph") replace
graph export "figures\figure_1.png", as(png) name("Graph") replace


*** Figure 2
twoway (connected share_div_board year, msize(tiny) msymbol(diamond) mcolor(black) lcolor(black)) (connected share_div_agm year, msize(tiny) mcolor(gs5) lcolor(gs5) lpattern(dot)) (connected share_div_auto year, msymbol(square) msize(tiny) mcolor(gs10) lcolor(gs10) lpattern(dash)), xline(1884 1900, lcolor(black%50)) ylabel(, nogrid) ytitle("Share distribution rule", margin(small)) note("") graphregion(fcolor(white) lcolor(none) lwidth(none)) subtitle(, fcolor(gs10) lcolor(black)) legend(order(1 "Board decides" 2 "AGM decides" 3 "Automatic distribution"))
graph export "figures\figure_2.pdf", as(pdf) name("Graph") replace
graph export "figures\figure_2.png", as(png) name("Graph") replace


********************************************************************************
***********************************Figure 3*************************************
********************************************************************************
use "dividend_policy_panel.dta", clear
*Count variable for firms in sample
generate number_firms = 1

*count variables for increase/decrease div, by firm
sort firmennr year
generate div_increase = 1 if DIV[_n]>DIV[_n-1] & firmennr[_n] == firmennr[_n-1] & DIV[_n-1]!=. & DIV[_n]!=.
generate div_decrease = 1 if DIV[_n]<DIV[_n-1] & firmennr[_n] == firmennr[_n-1] & DIV[_n-1]!=. & DIV[_n]!=.
generate div_constant = 1 if DIV[_n]==DIV[_n-1] & firmennr[_n] == firmennr[_n-1] & DIV[_n-1]!=. & DIV[_n]!=.

*count variable number firms that paid dividend
collapse (sum) number_firms pay_div div_increase div_decrease div_constant if T>=4, by(year)

* mean share div payers
generate share_div = pay_div/number_firms
label var share_div "Share div. payer (annually)"

egen mean_div_payer = mean(share_div)
label var mean_div_payer "Share div. payer (mean)"
* --> The overall mean of the share of corporations that paid a dividend is: 0.94

*reverse dividend decrease
generate div_decrease_neg = div_decrease*(-1)

twoway (line number_firms year, lcolor(black) lstyle(solid)) (line pay_div year, lcolor(black) lpattern(dash)) (bar div_increase year, fcolor(gs10) lcolor(black)) (bar div_decrease_neg year, fcolor(gs16) lcolor(black)), xtitle("") xlabel(1870(5)1910, ticks) xmticks(##5) ylabel(-40 "40" -20 "20" 0 "0" 20 "20" 40 "40" 60 "60" 80 "80", angle(horizontal) nogrid) legend(on order(1 "# firms in sample" 2 "# div. payer" 3 "# div. increase" 4 "# div.decrease")position(11) ring(0) col(1) size(*0.6) symxsize(*0.6) region(lstyle(none)) region(col(none))) graphregion(fcolor(white) lcolor(none) lwidth(none))
graph export "figures\figure_3.pdf", as(pdf) name("Graph") replace
graph export "figures\figure_3.png", as(png) name("Graph") replace

********************************************************************************
************************************Figure 4************************************
********************************************************************************
use "dividend_policy_panel.dta", clear
*mean dividend payout ratio (annually)
egen mean_DPAR = mean(DPAR) if T>=4, by(year)
bysort year (mean_DPAR) : replace mean_DPAR = mean_DPAR[_n-1] if missing(mean_DPAR) & _n > 1
egen byte flag = tag(year) // tag --> picks only one observation by year 

twoway (scatter DPAR year if T>=4, msize(small) mcolor(gs8) color(%30)) (scatter mean_DPAR year if flag==1, msize(small) mcolor(black%80)), xtitle("",margin(medsmall) ) xlabel(1870(5)1910, ticks) xmticks(##5) ytitle("") ylabel(0 "0" .25 "0.25" .5 "0.5" .75 "0.75" 1 "1" 1.25 "1.25" , nogrid angle(horizontal)) legend(on order(1 "Dividend Pay-Out Ratio" 2 "Mean") position(10) ring(0) col(1) region(lstyle(none)) region(col(white))) graphregion(fcolor(white) lcolor(none) lwidth(none))
graph export "figures\figure_4.pdf", as(pdf) name("Graph") replace
graph export "figures\figure_4.png", as(png) name("Graph") replace

********************************************************************************
************************************Figure 5************************************
********************************************************************************
use "dividend_policy_panel.dta", clear
*mean dividend (annually)
egen mean_DIV = mean(DIV) if T>=4, by(year)
bysort year (mean_DIV) : replace mean_DIV = mean_DIV[_n-1] if missing(mean_DIV) & _n > 1
egen byte flag = tag(year) // tag --> picks only one observation by year 

twoway (scatter DIV year if T>=4, msize(small) mcolor(gs8) color(%30)) (scatter mean_DIV year if flag==1, msize(small) mcolor(black%80)), xtitle("",margin(medsmall) ) xlabel(1870(5)1910, ticks) xmticks(##5) ytitle("") ylabel(, nogrid angle(horizontal)) legend(on order(1 "Dividend pct. of share capital" 2 "Mean") position(1) ring(0) col(1) region(lstyle(none)) region(col(white))) graphregion(fcolor(white) lcolor(none) lwidth(none))
graph export "figures\figure_5.pdf", as(pdf) name("Graph") replace
graph export "figures\figure_5.png", as(png) name("Graph") replace

graph close

********************************************************************************